/*
 * FILE:    batchconvertdialog.h
 * PACKAGE: PNML view
 * LICENCE: See LICENCE file
 * AUTHOR:  Freek van Walderveen
 *
 */

#ifndef BATCHCONVERTDIALOG_H
#define BATCHCONVERTDIALOG_H

#include ".ui/ui_batchconvertdialog.h"
#include "drawprops.h"

#include <QDialog>
#include <QVector>
#include <QTextStream>

class QCheckBox;
class Net;
class Connectable;
class DrawProps;

class BatchConvertDialog : public QDialog {
  Q_OBJECT

public:
  BatchConvertDialog(DrawProps *dp, QWidget * parent = 0, Qt::WFlags flags = 0); // Pre: dp
  virtual ~BatchConvertDialog();
  
protected:
  void addVectorFormat(QString format, bool checked = false);
  void addRasterFormat(QString format, bool checked = false);
  void recurseExportNet(Net *net, QString baseFileName); // Pre: net
  void exportNet(Net *net, QString baseFileName); // Pre: net

private slots:
  void on_addFilesButton_clicked();
  void on_browseButton_clicked();
  void on_browseLatexButton_clicked();
  void on_convertButton_clicked();
  void on_closeButton_clicked();

private:
  static QString replaceSpecialPathChars(QString str);
  static QString latexFormat(QString str, bool noEndl = false);
  static const QString setJoin(const QVector<Connectable *> set, const QString setName, const QString join);

  // { inv: all pointers are non-NULL and valid }
  Ui::BatchConvertDialog ui;
  QVBoxLayout *vectorGroupBoxLayout;
  QVBoxLayout *rasterGroupBoxLayout;
  
  QVector<QCheckBox *> vectorCheckBoxes;
  QVector<QCheckBox *> rasterCheckBoxes;
  
  DrawProps drawProps;
  QString lastInputDir;
  QTextStream latexStream;
};

#endif //~BATCHCONVERTDIALOG_H
