/*
 * FILE:    connectable.cpp
 * PACKAGE: PNML view
 * LICENCE: See LICENCE file
 * AUTHOR:  Freek van Walderveen
 *
 */

#include "connectable.h"
#include "arc.h"

Connectable::Connectable() {
}

Connectable::~Connectable() {
}

QString Connectable::markup(QString str, QString header /* = QString()*/, bool monoSpaced /*= false*/) const {
  str = str.trimmed();
  str.replace('<', "&lt;");
  str.replace('>', "&gt;");
  header.replace('<', "&lt;");
  header.replace('>', "&gt;");
  str.replace('\n', "<br />");
  
  if (str.isEmpty()) {
    return QString();
  } else {
    if (!header.isEmpty()) {
      header = "<br /><i>" + header + "</i><br />";
    }
    if (monoSpaced) {
      return header + "<pre>" + str + "</pre><br />";
    } else {
      return header + str + "<br />";
    }
  }
}

const QString Connectable::getToolTip() const {
  QString text = name;
  if (text.isEmpty()) {
    text = id;
  } else {
    text.replace('<', "&lt;");
    text.replace('>', "&gt;");
    text = QString("<b>") + text + "</b> (" + id +")";
  }
  
  text += "<br />" + markup(description);
  return text;
}

bool Connectable::containsPos(QPoint pos) const {
  return QRect(position.x() - size.width()/2,
               position.y() - size.height()/2,
               size.width(),
               size.height()).contains(pos);
}

const QVector<Connectable *> Connectable::getPreSet() const {
  QVector<Connectable *> set;
  foreach (Arc *arc, arcs) {
    if (arc->getType() == Arc::Standard &&
        arc->getTarget() == this &&
        arc->getSource()) {
      set << arc->getSource();
    }
  }
  return set;
}

const QVector<Connectable *> Connectable::getPostSet() const {
  QVector<Connectable *> set;
  foreach (Arc *arc, arcs) {
    if (arc->getType() == Arc::Standard &&
        arc->getSource() == this &&
        arc->getTarget()) {
      set << arc->getTarget();
    }
  }
  return set;
}

const QVector<Connectable *> Connectable::getAssocStores() const {
  QVector<Connectable *> set;
  foreach (Arc *arc, arcs) {
    if (arc->getType() == Arc::StoreAction) {
      if (arc->getSource() == this && arc->getTarget()) {
        set << arc->getTarget();
      } else if (arc->getTarget() == this && arc->getSource()) {
        set << arc->getSource();
      } 
    }
  }
  return set;
}

const QVector<Connectable *> Connectable::getInhibits() const {
  QVector<Connectable *> set;
  foreach (Arc *arc, arcs) {
    if (arc->getType() == Arc::Inhibitor) {
      if (arc->getSource() == this && arc->getTarget()) {
        set << arc->getTarget();
      } else if (arc->getTarget() == this && arc->getSource()) {
        set << arc->getSource();
      } 
    }
  }
  return set;
}

const QVector<Connectable *> Connectable::getResets() const {
  QVector<Connectable *> set;
  foreach (Arc *arc, arcs) {
    if (arc->getType() == Arc::Reset) {
      if (arc->getSource() == this && arc->getTarget()) {
        set << arc->getTarget();
      } else if (arc->getTarget() == this && arc->getSource()) {
        set << arc->getSource();
      } 
    }
  }
  return set;
}
