/*
 * FILE:    mainwindow.h
 * PACKAGE: PNML view
 * LICENCE: See LICENCE file
 * AUTHOR:  Freek van Walderveen
 *
 */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include "drawprops.h"
#include ".ui/ui_mainwindow.h"

#include <QMainWindow>
#include <QDateTime>

class DrawWidget;
class QScrollArea;
class Net;

class MainWindow : public QMainWindow {
  Q_OBJECT

public:
  MainWindow(QWidget * parent = 0, Qt::WFlags flags = 0);
  virtual ~MainWindow();
  
  void openFile(QString fileName);
  
protected:
  void setActionsEnabled(bool value);
  virtual void closeEvent(QCloseEvent *e);
  virtual void enterEvent(QEvent *e);

private slots:
  void updateAll();

  void on_actionOpen_triggered();
  void on_actionPreferences_triggered();
  void on_actionPrint_triggered();
  void on_actionExportPDF_triggered();
  void on_actionExportEPS_triggered();
#ifdef QT3_SUPPORT
  void on_actionExportSVG_triggered();
#endif
  void on_actionExportRaster_triggered();
  void on_actionBatchConvert_triggered();
  void on_actionZoomIn_triggered();
  void on_actionZoomOut_triggered();
  void on_actionZoomFull_triggered();
  void on_actionAbout_triggered();
  void on_actionAboutQt_triggered();
  void on_namesCheckBox_toggled(bool checked);
  void on_rolesCheckBox_toggled(bool checked);
  void on_toolTipsCheckBox_toggled(bool checked);
  void on_hierarchyTreeWidget_itemClicked(QTreeWidgetItem *item, int column);

private:
  DrawProps drawProps;

  Ui::MainWindow ui;
  QScrollArea *scrollArea;
  DrawWidget *drawArea;
  
  Net *net; // root net, may be null
  
  QString lastPath;
  QString lastExportPath;
  QString lastImageFormat;
  QString currentFile;
  QDateTime currentFileLastModified;
  
};

#endif //~MAINWINDOW_H
